Ext.namespace('dSS', 'dSS.data');

dSS.data.SceneStore = Ext.extend(Ext.data.Store, {
    constructor: function(config) {
        // create a record constructor for zone records
        var sceneRecord = Ext.data.Record.create([
        {
            name: 'id'
        },
        {
            name: 'name'
        },
        {
            name: 'scene'
        },
        {
            name: 'group'
        },
        {
            name: 'zone'
        }]);

        // a json reader to read the zone data
        var sceneReader = new Ext.data.JsonReader({
            root: 'scenes'
        },
        sceneRecord);

        Ext.apply(this, {
            reader: sceneReader
        });

        dSS.data.SceneStore.superclass.constructor.call(this, arguments);
    },

    loadScenes: function() {
        Ext.Ajax.request({
            url: '/json/property/query',
            params: { 
                query: '/apartment/zones/*(ZoneID,scenes)/groups/*(group)/scenes/*(scene,name)'
            },
            disableCaching: true,
            timeout: 300000,
            method: "GET",
            scope: this,
            success: function(result, request) {
                try {
                    var jsonData = Ext.util.JSON.decode(result.responseText);
                    this.processScenes(jsonData.result);
                }
                catch(err) {
                    Ext.MessageBox.alert(dSS._("Error"), dSS._("Could not load scene information") + ": \"" + err + "\"");
                }
            },
            failure: function(result, request) {
                Ext.MessageBox.alert(dSS._("Error"), dSS._("Could not load") + ": \"" + request.url + "\"");
            }
        });
    },

    processScenes: function(sceneData) {
        var sceneStore = this.sceneStore;
        var scenes = [];

        Ext.each(sceneData.zones, function(zone) {
            if (zone.groups === undefined) {
                return true;
            }
            Ext.each(zone.groups, function(group) {
                if (group.scenes === undefined) {
                    return true;
                }
                Ext.each(group.scenes, function(scene) {
                    scenes.push({
                        id: zone.ZoneID + '-' + group.group + '-' + scene.scene,
                        name: scene.name,
                        scene: scene.scene,
                        group: group.group,
                        zone: zone.ZoneID
                    });
                });
            });
        });

        this.loadData({ scenes: scenes });
    }
});

